@@ -14,11 +14,9 @@
 """
 
 from emoji.core import emojize
+
 from hspylib.core.enums.enumeration import Enumeration
-
-
-def emj_print(emoji_str: str) -> None:
-    print(emojize(emoji_str) + ' ', end='')
+from hspylib.core.tools.commons import sysout
 
 
 class Emoji(Enumeration):
@@ -28,6 +26,10 @@ class Emoji(Enumeration):
           - https://unicode.org/emoji/charts/emoji-list.html
     """
 
+    @staticmethod
+    def emj_print(emoji_str: str, end: str = '') -> None:
+        sysout(f"{emojize(emoji_str)} ", end=end)
+
     def __str__(self) -> str:
         return str(self.value)
 
